import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useMemo } from 'react';
import { ThemeProvider, BaseStyles } from "@primer/react";
import { ErrorBoundary } from 'react-error-boundary';
import { JupyterContextProvider } from './JupyterContext';
import { getJupyterServerHttpUrl, getJupyterServerWsUrl, loadJupyterConfig } from './JupyterConfig';
import defaultInjectableStore from '../state/redux/Store';
/**
 * The component to be used as fallback in case of error.
 */
const ErrorFallback = ({ error, resetErrorBoundary }) => {
    return (_jsxs("div", { role: "alert", children: [_jsx("p", { children: "Oops, something went wrong." }), _jsx("pre", { children: error.message }), _jsx("div", { style: { visibility: "hidden" }, children: _jsx("button", { onClick: resetErrorBoundary, children: "Try again" }) })] }));
};
/**
 * The Jupyter context. This handles the needed initialization
 * and ensure the Redux and the Material UI theme providers
 * are available.
 */
export const Jupyter = (props) => {
    const { lite, startDefaultKernel, defaultKernelName, injectableStore, useRunningKernelId, useRunningKernelIndex, children, disableCssLoading, } = props;
    const config = useMemo(() => loadJupyterConfig(props), []);
    useEffect(() => {
        if (!config.insideJupyterLab) {
            if (!disableCssLoading) {
                import("./lab/JupyterLabCss");
            }
        }
    }, [config]);
    return (_jsx(ErrorBoundary, { FallbackComponent: ErrorFallback, onReset: () => { console.log('Error Boundary reset has been invoked...'); }, children: _jsx(ThemeProvider, { colorMode: "day", children: _jsx(BaseStyles, { children: _jsx(JupyterContextProvider, { baseUrl: getJupyterServerHttpUrl(), defaultKernelName: defaultKernelName, disableCssLoading: disableCssLoading, injectableStore: injectableStore || defaultInjectableStore, lite: lite, startDefaultKernel: startDefaultKernel, useRunningKernelId: useRunningKernelId, useRunningKernelIndex: useRunningKernelIndex ?? -1, variant: "default", wsUrl: getJupyterServerWsUrl(), children: children }) }) }) }));
};
Jupyter.defaultProps = {
    collaborative: false,
    defaultKernelName: 'python',
    disableCssLoading: false,
    lite: false,
    startDefaultKernel: true,
    terminals: false,
    useRunningKernelIndex: -1,
};
export default Jupyter;
//# sourceMappingURL=Jupyter.js.map